package akvkeys
import "github.com/microsoft/go-mssqldb/internal/akvkeys"
Index ¶
- func CreateRSAKey(client *azkeys.Client) (name string, err error)
- func DeleteRSAKey(client *azkeys.Client, name string) bool
- func GetProviderCredential() (cred azcore.TokenCredential, err error)
- func GetTestAKV() (client *azkeys.Client, u string, err error)
Functions ¶
func CreateRSAKey ¶
func DeleteRSAKey ¶
func GetProviderCredential ¶
func GetProviderCredential() (cred azcore.TokenCredential, err error)
GetProviderCredential retrieves the Azure credential for accessing Azure Key Vault
func GetTestAKV ¶
GetTestAKV retrieves an Azure Key Vault client for testing purposes.
Source Files ¶
- Version
- v1.10.0 (latest)
- Published
- Apr 30, 2026
- Platform
- linux/amd64
- Imports
- 9 packages
- Last checked
- 8 minutes ago –
Tools for package owners.